@@ -9,9 +9,10 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type, Union
 
 import aiohttp
 
+from .errors import Unauthorized
 from .http import HTTPClient
 from .oauth2 import OAuth2Token
-from .role import RoleMetadataRecord, RolePlatform
+from .role import RoleConnection, RoleMetadataRecord
 from .user import User
 from .utils import MISSING
 
@@ -75,7 +76,7 @@ class LinkedRolesOAuth2:
         client_secret: Optional[str] = None,
         redirect_uri: Optional[str] = None,
         token: Optional[str] = None,
-        scopes=('role_connections.write', 'identify'),
+        scopes: Tuple[str, ...] = (),
         state: Optional[str] = None,
         proxy: Optional[str] = None,
         proxy_auth: aiohttp.BasicAuth = MISSING,
@@ -94,7 +95,7 @@ class LinkedRolesOAuth2:
             token=token,
         )
         self._role_metadata: Dict[str, RoleMetadataRecord] = {}
-        self._users: Dict[str, User] = {}
+        self._users: Dict[int, User] = {}
         self._role_metadat_is_fetched: bool = False
         self._is_closed: bool = False
 
@@ -174,9 +175,9 @@ class LinkedRolesOAuth2:
         """
         return self._http.get_oauth_url()
 
-    async def get_oauth2_tokens(self, code: str) -> OAuth2Token:
+    async def get_access_token(self, code: str) -> OAuth2Token:
         """
-        Gets the OAuth2 tokens.
+        Gets the access token.
         Parameters
         ----------
         code : :class:`str`
@@ -186,7 +187,7 @@ class LinkedRolesOAuth2:
         :class:`OAuth2Token`
             The OAuth2 token.
         """
-        data = await self._http.get_oauth2_tokens(code)
+        data = await self._http.get_oauth2_token(code)
         return OAuth2Token(self, data)
 
     async def register_role_metadata(
@@ -228,26 +229,26 @@ class LinkedRolesOAuth2:
         """
         return self._role_metadata.get(key)
 
-    async def fetch_user(self, tokens: OAuth2Token) -> Optional[User]:
+    async def fetch_user(self, token: OAuth2Token) -> Optional[User]:
         """
         Fetches the user.
         Parameters
         ----------
-        tokens : :class:`OAuth2Token`
+        token : :class:`OAuth2Token`
             The OAuth2 token.
         Returns
         -------
         Optional[:class:`User`]
             The user.
         """
-        data = await self._http.get_user(tokens.access_token)
+        data = await self._http.get_user(token.access_token)
         if data is None:
             return None
-        user = User(self, data, tokens=tokens)
-        self._users[str(user.id)] = user
+        user = User(self, data, token)
+        self._users[int(user.id)] = user
         return user
 
-    def get_user(self, id: Union[str, int]) -> Optional[User]:
+    def get_user(self, id: int) -> Optional[User]:
         """
         Gets the user by it's id.
         Parameters
@@ -259,42 +260,33 @@ class LinkedRolesOAuth2:
         Optional[:class:`User`]
             The user.
         """
-        return self._users.get(str(id))
+        return self._users.get(id)
 
-    async def edit_user_role_connection(self, user: User, platform: RolePlatform) -> Optional[RolePlatform]:
+    async def is_authenticated(self, token: Union[OAuth2Token, str]) -> bool:
         """
-        Edits the user application role connection.
+        Checks if the user is authenticated.
         Parameters
         ----------
-        user : :class:`User`
-            The user.
-        platform : :class:`RolePlatform`
-            The role platform.
+        token : Union[:class:`OAuth2Token`, :class:`str`]
+            The OAuth2 token.
         Returns
         -------
-        Optional[:class:`RolePlatform`]
-            The role platform.
+        :class:`bool`
+            Whether the user is authenticated.
         """
-        tokens = user.get_tokens()
-        if tokens is None:
-            raise ValueError('User does not have tokens')
-        after = await self._http.put_user_application_role_connection(tokens.access_token, platform.to_dict())
-        if after is not None:
-            platform = RolePlatform.from_dict(after)
-            try:
-                await self.on_user_application_role_connection_update(
-                    user=user, before=user.__orginal_role_platform__ or platform, after=platform
-                )
-            except Exception as e:
-                _log.error(f'event on_user_application_role_connection_update raised an exception: {e}')
-            user.__orginal_role_platform__ = platform
-        return platform
+        access_token = token.access_token if isinstance(token, OAuth2Token) else token
+        try:
+            await self._http.get_user(access_token)
+        except Unauthorized:
+            return False
+        else:
+            return True
 
     async def on_user_application_role_connection_update(
         self,
         user: User,
-        before: RolePlatform,
-        after: RolePlatform,
+        before: RoleConnection,
+        after: RoleConnection,
     ) -> None:
         """
         Called when a user's application role connection is updated.
@@ -302,9 +294,9 @@ class LinkedRolesOAuth2:
         ----------
         user : :class:`User`
             The user.
-        before : :class:`RolePlatform`
-            The role platform before the update.
-        after : :class:`RolePlatform`
-            The role platform after the update.
+        before : :class:`RoleConnection`
+            The role connection before the update.
+        after : :class:`RoleConnection`
+            The role connection after the update.
         """
         pass
